@@ -24,45 +24,45 @@ spark_dependencies <- function(spark_version, scala_version, ...) {
       latest <- read.table("http://s3.amazonaws.com/h2o-release/sparkling-water/rel-2.1/latest")
       sw_version <- sprintf("2.1.%s",latest)
       message(sprintf("Spark version %s detected. Will call latest Sparkling Water version %s",spark_version,sw_version))
-      if (packageVersion("h2o") != "3.10.3.2") {
-        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.10.3.2, which is compliant with the latest Sparkling Water version for Spark 2.1.* -> Sparkling Water version ', sw_version,'\n
+      if (packageVersion("h2o") != "3.10.5.2") {
+        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.10.5.2, which is compliant with the latest Sparkling Water version for Spark 2.1.* -> Sparkling Water version ', sw_version,'\n
 To update your h2o R package, copy/paste the following commands and then restart your R session:
                        
   detach("package:rsparkling", unload = TRUE)
   if ("package:h2o" %in% search()) { detach("package:h2o", unload = TRUE) }
   if (isNamespaceLoaded("h2o")){ unloadNamespace("h2o") }
   remove.packages("h2o")
-  install.packages("h2o", type = "source", repos = "http://h2o-release.s3.amazonaws.com/h2o/rel-tverberg/2/R")\n'))
+  install.packages("h2o", type = "source", repos = "http://h2o-release.s3.amazonaws.com/h2o/rel-ueno/8/R")\n'))
       }
     }else if (as.package_version(spark_version)$major == "2") {
       #Get latest Sparkling Water release for Spark 2.0.*
       latest <- read.table("http://s3.amazonaws.com/h2o-release/sparkling-water/rel-2.0/latest")
       sw_version <- sprintf("2.0.%s",latest)
       message(sprintf("Spark version %s detected. Will call latest Sparkling Water version %s",spark_version,sw_version))
-      if (packageVersion("h2o") != "3.10.3.2") {
-        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.10.3.2, which is compliant with the latest Sparkling Water version for Spark 2.0.* ->  Sparkling Water version ', sw_version,'\n
+      if (packageVersion("h2o") != "3.10.5.2") {
+        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.10.5.2, which is compliant with the latest Sparkling Water version for Spark 2.0.* ->  Sparkling Water version ', sw_version,'\n
 To update your h2o R package, copy/paste the following commands and then restart your R session:
 
   detach("package:rsparkling", unload = TRUE)
   if ("package:h2o" %in% search()) { detach("package:h2o", unload = TRUE) }
   if (isNamespaceLoaded("h2o")){ unloadNamespace("h2o") }
   remove.packages("h2o")
-  install.packages("h2o", type = "source", repos = "http://h2o-release.s3.amazonaws.com/h2o/rel-tverberg/2/R")\n'))
+  install.packages("h2o", type = "source", repos = "http://h2o-release.s3.amazonaws.com/h2o/rel-ueno/8/R")\n'))
       }
     } else if (as.package_version(spark_version)$major == "1" && as.package_version(spark_version)$minor == "6" ) { #Assuming Spark 1.6
       #Get latest Sparkling Water release for Spark 1.6.*
       latest <- read.table("http://s3.amazonaws.com/h2o-release/sparkling-water/rel-1.6/latest")
       sw_version <- sprintf("1.6.%s",latest) 
       message(sprintf("Spark version %s detected. Will call latest Sparkling Water version %s",spark_version,sw_version))
-      if (packageVersion("h2o") != "3.10.0.7"){
-        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.10.0.7, which is compliant with the latest Sparkling Water version for Spark 1.6.* ->  Sparkling Water version ', sw_version,'\n
+      if (packageVersion("h2o") != "3.10.5.2"){
+        message(paste0('\nDetected H2O version ', packageVersion("h2o"),'. Please install H2O version 3.10.5.2, which is compliant with the latest Sparkling Water version for Spark 1.6.* ->  Sparkling Water version ', sw_version,'\n
 To update your h2o R package, copy/paste the following commands and then restart your R session:
 
   detach("package:rsparkling", unload = TRUE)
   if ("package:h2o" %in% search()) { detach("package:h2o", unload = TRUE) }
   if (isNamespaceLoaded("h2o")){ unloadNamespace("h2o") }
   remove.packages("h2o")
-  install.packages("h2o", type = "source", repos = "http://h2o-release.s3.amazonaws.com/h2o/rel-turing/7/R")\n'))
+  install.packages("h2o", type = "source", repos = "http://h2o-release.s3.amazonaws.com/h2o/rel-ueno/8/R")\n'))
       }
     } else {
       stop("Spark installation 1.6.*, 2.0.*, or 2.1.* are not detected. Please install Spark 1.6.*, 2.0.*, or 2.1.*")
@@ -89,7 +89,8 @@ To update your h2o R package, copy/paste the following commands and then restart
     spark_dependency(packages = c(
       sprintf("ai.h2o:sparkling-water-core_%s:%s", scala_version, sw_version),
       sprintf("ai.h2o:sparkling-water-ml_%s:%s", scala_version, sw_version),
-      sprintf("ai.h2o:sparkling-water-repl_%s:%s", scala_version, sw_version)
+      sprintf("ai.h2o:sparkling-water-repl_%s:%s", scala_version, sw_version),
+      sprintf("no.priv.garshol.duke:duke:1.2")
     ))
   }
 }
